# Bundled pshmem

This directory contains the v0.1.0 release of the pshmem package:

https://github.com/tskisner/pshmem

Once that package is widely available on PyPI and conda-forge, we can stop bundling
it here and just import it.
